@@ -308,8 +308,10 @@ percent_dict_reused_key = """a = '%(?)s %(?)s' % {'?': var}"""
 
 
 def test_percent_dict_reused_key_noop():
-    assert (process.fstringify_code_by_line(percent_dict_reused_key)[0] ==
-            percent_dict_reused_key)
+    assert (
+        process.fstringify_code_by_line(percent_dict_reused_key)[0]
+        == percent_dict_reused_key
+    )
 
 
 def test_percent_dict_reused_key_aggressive(aggressive):
